@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2005-2021, PyInstaller Development Team.
+# Copyright (c) 2005-2023, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License (version 2
 # or later) with exception for distributing the bootloader.
@@ -8,17 +8,15 @@
 #
 # SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
 #-----------------------------------------------------------------------------
-
-
 """
 Configure PyInstaller for the current Python installation.
 """
 
 import os
 
-from . import compat
-from . import log as logging
-from .compat import is_win, is_darwin
+from PyInstaller import compat
+from PyInstaller import log as logging
+from PyInstaller.compat import is_darwin, is_win
 
 logger = logging.getLogger(__name__)
 
@@ -31,8 +29,7 @@ def test_UPX(config, upx_dir):
 
     hasUPX = 0
     try:
-        vers = compat.exec_command(
-            cmd, '-V', __raise_ENOENT__=True).strip().splitlines()
+        vers = compat.exec_command(cmd, '-V', raise_enoent=True).strip().splitlines()
         if vers:
             v = vers[0].split()[1]
             try:
@@ -42,14 +39,14 @@ def test_UPX(config, upx_dir):
                 pass
             hasUPX = tuple(map(int, v.split(".")))
             if is_win and hasUPX < (1, 92):
-                logger.error('UPX is too old! Python 2.4 under Windows requires UPX 1.92+')
+                logger.error('UPX is too old! Python 2.4 under Windows requires UPX 1.92+.')
                 hasUPX = 0
     except Exception as e:
         if isinstance(e, OSError) and e.errno == 2:
             # No such file or directory
             pass
         else:
-            logger.info('An exception occured when testing for UPX:')
+            logger.info('An exception occurred when testing for UPX:')
             logger.info('  %r', e)
     if hasUPX:
         is_available = 'available'
@@ -65,14 +62,13 @@ def _get_pyinst_cache_dir():
     if compat.getenv('PYINSTALLER_CONFIG_DIR'):
         cache_dir = compat.getenv('PYINSTALLER_CONFIG_DIR')
     elif is_win:
-        cache_dir = compat.getenv('APPDATA')
+        cache_dir = compat.getenv('LOCALAPPDATA')
         if not cache_dir:
             cache_dir = os.path.expanduser('~\\Application Data')
     elif is_darwin:
         cache_dir = os.path.expanduser('~/Library/Application Support')
     else:
-        # According to XDG specification
-        # http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
+        # According to XDG specification: http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
         old_cache_dir = compat.getenv('XDG_DATA_HOME')
         if not old_cache_dir:
             old_cache_dir = os.path.expanduser('~/.local/share')
@@ -80,7 +76,7 @@ def _get_pyinst_cache_dir():
         if not cache_dir:
             cache_dir = os.path.expanduser('~/.cache')
     cache_dir = os.path.join(cache_dir, 'pyinstaller')
-    # Move old cache-dir, if any, to now location
+    # Move old cache-dir, if any, to new location.
     if old_cache_dir and not os.path.exists(cache_dir):
         old_cache_dir = os.path.join(old_cache_dir, 'pyinstaller')
         if os.path.exists(old_cache_dir):
