@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 PyInstaller Development Team.
+# Copyright (C) 2017-2023 PyInstaller Development Team.
 # Copyright (C) 2016 Jason R Coombs <jaraco@jaraco.com>
 #
 # This file includes an almost complete copy of
@@ -30,12 +30,12 @@
 #--- Code of pkg_resources/extern/__init__.py starts here
 import sys
 
+
 class VendorImporter:
     """
-    A PEP 302 meta path importer for finding optionally-vendored
-    or otherwise naturally-installed packages from root_name.
+    A PEP 302 meta path importer for finding optionally-vendored or otherwise naturally-installed
+    packages from root_name.
     """
-
     def __init__(self, root_name, vendored_names=(), vendor_pkg=None):
         self.root_name = root_name
         self.vendored_names = set(vendored_names)
@@ -51,8 +51,7 @@ class VendorImporter:
 
     def find_module(self, fullname, path=None):
         """
-        Return self when fullname starts with root_name and the
-        target module is one vendored through this importer.
+        Return self when fullname starts with root_name and the target module is one vendored through this importer.
         """
         root, base, target = fullname.partition(self.root_name + '.')
         if root:
@@ -72,11 +71,9 @@ class VendorImporter:
                 __import__(extant)
                 mod = sys.modules[extant]
                 sys.modules[fullname] = mod
-                # mysterious hack:
-                # Remove the reference to the extant package/module
-                # on later Python versions to cause relative imports
-                # in the vendor package to resolve the same modules
-                # as those going through this importer.
+                # mysterious hack: Remove the reference to the extant package/module on later Python versions to cause
+                # relative imports in the vendor package to resolve the same modules as those going through this
+                # importer.
                 if sys.version_info > (3, 3):
                     del sys.modules[extant]
                 return mod
@@ -84,11 +81,10 @@ class VendorImporter:
                 pass
         else:
             raise ImportError(
-                "The '{target}' package is required; "
-                "normally this is bundled with this package so if you get "
-                "this warning, consult the packager of your "
-                "distribution.".format(**locals())
+                "The '{target}' package is required; normally this is bundled with this package so if you get "
+                "this warning, consult the packager of your distribution.".format(**locals())
             )
+
     def install(self):
         """
         Install this importer into sys.meta_path if not already present.
@@ -96,7 +92,9 @@ class VendorImporter:
         if self not in sys.meta_path:
             sys.meta_path.append(self)
 
-#--- Code of pkg_resources/extern/__init__.py ends here
+
+# --- Code of pkg_resources/extern/__init__.py ends here
+
 
 class MyVendorImporter(VendorImporter):
     @property
@@ -106,5 +104,6 @@ class MyVendorImporter(VendorImporter):
         """
         yield self.vendor_pkg + '.'
 
+
 names = ('aaa', 'bbb', 'ccc')
 MyVendorImporter(__name__, names).install()
