@@ -154,3 +154,31 @@ def test_single_file_metadata(pyi_builder):
         """,
         pyi_args=['--paths', extra_path]
     )
+
+
+# Test that we can successfully package a program even if one of its modules contains non-ASCII characters in a local
+# (non-UTF8) encoding and fails to declare such encoding using PEP361 encoding header.
+def test_program_importing_module_with_invalid_encoding1(pyi_builder):
+    # Add directory containing the my-test-package metadata to search path
+    extra_path = os.path.join(_MODULES_DIR, "pyi_module_with_invalid_encoding")
+
+    pyi_builder.test_source(
+        """
+        import mymodule1
+        assert mymodule1.hello() == "hello"
+        """,
+        pyi_args=['--paths', extra_path]
+    )
+
+
+def test_program_importing_module_with_invalid_encoding2(pyi_builder):
+    # Add directory containing the my-test-package metadata to search path
+    extra_path = os.path.join(_MODULES_DIR, "pyi_module_with_invalid_encoding")
+
+    pyi_builder.test_source(
+        """
+        import mymodule2
+        assert mymodule2.hello() == "hello"
+        """,
+        pyi_args=['--paths', extra_path]
+    )
