@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2005-2021, PyInstaller Development Team.
+# Copyright (c) 2005-2023, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License (version 2
 # or later) with exception for distributing the bootloader.
@@ -9,63 +9,73 @@
 # SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
 #-----------------------------------------------------------------------------
 
-
 import os
 import pytest
 import textwrap
 
 from PyInstaller.depend import utils
-from PyInstaller.compat import is_unix, is_win
-
+from PyInstaller.compat import is_win, is_musl, is_macos_11_compat
 
 CTYPES_CLASSNAMES = (
-    'CDLL',   'ctypes.CDLL',
+    'CDLL', 'ctypes.CDLL',
     'WinDLL', 'ctypes.WinDLL',
     'OleDLL', 'ctypes.OleDLL',
-    'PyDLL',  'ctypes.PyDLL')
+    'PyDLL', 'ctypes.PyDLL',
+)  # yapf: disable
 
 
-def __scan_code_for_ctypes(code, monkeypatch):
+def __scan_code_for_ctypes(code, monkeypatch, extended_args):
     # _resolveCtypesImports would filter our some of our names
-    monkeypatch.setattr(utils, '_resolveCtypesImports',
-                        lambda cbinaries: cbinaries)
+    monkeypatch.setattr(utils, '_resolveCtypesImports', lambda cbinaries: cbinaries)
     code = textwrap.dedent(code)
+
+    if extended_args:
+        # Chuck in a load of preceding rubbish to test if the bytecode scanner can correctly
+        # handle the EXTENDED_ARGS opcode.
+        from test_bytecode import many_constants, many_globals
+        code = many_constants() + many_globals() + code
+
     co = compile(code, 'dummy', 'exec')
     #import pdb ; pdb.set_trace()
     return utils.scan_code_for_ctypes(co)
 
 
 @pytest.mark.parametrize('classname', CTYPES_CLASSNAMES)
-def test_ctypes_CDLL_call(monkeypatch, classname):
+@pytest.mark.parametrize('extended_args', [False, True])
+def test_ctypes_CDLL_call(monkeypatch, classname, extended_args):
     code = "%s('somelib.xxx')" % classname
-    res = __scan_code_for_ctypes(code, monkeypatch)
+    res = __scan_code_for_ctypes(code, monkeypatch, extended_args)
     assert res == set(['somelib.xxx'])
 
 
 @pytest.mark.parametrize('classname', CTYPES_CLASSNAMES)
-def test_ctypes_LibraryLoader(monkeypatch, classname):
-    # This type of useage is only valif on Windows and the lib-name will
-    # always get `.dll` appended.
+@pytest.mark.parametrize('extended_args', [False, True])
+def test_ctypes_LibraryLoader(monkeypatch, classname, extended_args):
+    # This type of usage is only valid on Windows and the lib-name will always get `.dll` appended.
     code = "%s.somelib" % classname.lower()
-    res = __scan_code_for_ctypes(code, monkeypatch)
+    res = __scan_code_for_ctypes(code, monkeypatch, extended_args)
     assert res == set(['somelib.dll'])
 
 
 @pytest.mark.parametrize('classname', CTYPES_CLASSNAMES)
-def test_ctypes_LibraryLoader_LoadLibrary(monkeypatch, classname):
+@pytest.mark.parametrize('extended_args', [False, True])
+def test_ctypes_LibraryLoader_LoadLibrary(monkeypatch, classname, extended_args):
     code = "%s.LoadLibrary('somelib.xxx')" % classname.lower()
-    res = __scan_code_for_ctypes(code, monkeypatch)
+    res = __scan_code_for_ctypes(code, monkeypatch, extended_args)
     assert res == set(['somelib.xxx'])
 
 
-def test_ctypes_util_find_library(monkeypatch):
+@pytest.mark.parametrize('extended_args', [False, True])
+@pytest.mark.skipif(is_musl, reason="find_library() doesn't work on musl")
+@pytest.mark.skipif(is_macos_11_compat, reason="find_library() requires python built with Big Sur support.")
+def test_ctypes_util_find_library(monkeypatch, extended_args):
     # for lind_library() we need a lib actually existing on the system
     if is_win:
         libname = "KERNEL32"
     else:
         libname = "c"
     code = "ctypes.util.find_library('%s')" % libname
-    res = __scan_code_for_ctypes(code, monkeypatch)
+    res = __scan_code_for_ctypes(code, monkeypatch, extended_args)
     assert res
 
 
@@ -86,6 +96,12 @@ def test_ctypes_util_find_library_as_default_argument():
 @pytest.mark.linux
 def test_ldconfig_cache():
     utils.load_ldconfig_cache()
+
+    if is_musl:
+        # load_ldconfig_cache() should be a no-op on musl because musl does not use ldconfig.
+        assert not utils.LDCONFIG_CACHE
+        return
+
     libpath = None
     for soname in utils.LDCONFIG_CACHE:
         if soname.startswith('libc.so.'):
