@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2005-2021, PyInstaller Development Team.
+# Copyright (c) 2005-2023, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License (version 2
 # or later) with exception for distributing the bootloader.
@@ -14,7 +14,7 @@ import pytest
 from PyInstaller.lib.modulegraph import modulegraph
 from PyInstaller import configure
 from PyInstaller import __main__ as pyi_main
-from PyInstaller.compat import is_py37, is_win
+from PyInstaller.compat import is_win
 
 
 @pytest.fixture
@@ -37,35 +37,31 @@ def large_import_chain(tmpdir):
     return [str(tmpdir)], str(script)
 
 
-def test_recursion_to_deep(large_import_chain):
+def test_recursion_too_deep(large_import_chain):
     """
-    modulegraph is recursive and thus triggers RecursionError if
-    nesting of imported modules is to deep. This can be worked around
-    by increasing recursion limit.
+    modulegraph is recursive and triggers RecursionError if nesting of imported modules is too deep.
+    This can be worked around by increasing recursion limit.
 
-    With the default recursion limit (1000), the recursion error
-    occurs at about 115 modules, with limit 2000 (as tested below) at
-    about 240 modules, with limit 5000 at about 660 modules.
+    With the default recursion limit (1000), the recursion error occurs at about 115 modules, with limit 2000
+    (as tested below) at about 240 modules, and with limit 5000 at about 660 modules.
     """
-    if is_py37 and is_win:
-        pytest.xfail("worker is know to crash for Py 3.7, 3.8 on Windows")
+    if is_win:
+        pytest.xfail("Worker is known to crash on Windows.")
     path, script = large_import_chain
     mg = modulegraph.ModuleGraph(path)
-    # Increase recursion limit to 5 times of the default. Given the
-    # module import chain created above this still should fail.
+    # Increase recursion limit to 5 times of the default. Given the module import chain created above
+    # this still should fail.
     with pytest.raises(RecursionError):
-        mg.run_script(str(script))
+        mg.add_script(str(script))
 
 
-def test_RecursionError_prints_message(tmpdir, large_import_chain,
-                                       monkeypatch):
+def test_RecursionError_prints_message(tmpdir, large_import_chain, monkeypatch):
     """
-    modulegraph is recursive and thus triggers RecursionError if
-    nesting of imported modules is to deep. Ensure a respective
-    informative message is printed if recursion error occurs.
+    modulegraph is recursive and triggers RecursionError if nesting of imported modules is too deep.
+    Ensure an informative message is printed if RecursionError occurs.
     """
-    if is_py37 and is_win:
-        pytest.xfail("worker is know to crash for Py 3.7, 3.8 on Windows")
+    if is_win:
+        pytest.xfail("Worker is known to crash on Windows.")
     path, script = large_import_chain
 
     default_args = [
@@ -73,7 +69,7 @@ def test_RecursionError_prints_message(tmpdir, large_import_chain,
         '--distpath', str(tmpdir.join("dist")),
         '--workpath', str(tmpdir.join("build")),
         '--path', str(tmpdir),
-    ]
+    ]  # yapf: disable
 
     pyi_args = [script] + default_args
     PYI_CONFIG = configure.get_config(upx_dir=None)
